//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Network for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
// This demo explains the steps to load an Outlook PST file and extract all Contacts from
// PST and save the contacts in VCard format to disk.
//==========================================================================================================//

import com.aspose.network.ContactSaveFormat;
import com.aspose.network.FolderInfo;
import com.aspose.network.MapiCalendar;
import com.aspose.network.MapiContact;
import com.aspose.network.MapiMessage;
import com.aspose.network.MessageInfo;
import com.aspose.network.MessageInfoCollection;
import com.aspose.network.PersonalStorage;
import java.io.File;

public class PSTExtractCalendar
{
    // Base folder to load and save files used in this demo
    private static String strBaseFolder = "D:\\Data\\Aspose\\resources\\";

    public static void main(String[] args)
    {
        // Set license
        setLicense();

        String pstFileName = strBaseFolder + "Outlook.pst";

        try
        {
            // load the Outlook PST file
            PersonalStorage pst = PersonalStorage.fromFile(pstFileName);

            // get the Contacts folder
            FolderInfo folderInfo = pst.getRootFolder().getSubFolder("Calendar");
            new File(strBaseFolder + "Calendar").mkdir();

            // loop through all the contacts in this folder
            MessageInfoCollection messageInfoCollection = folderInfo.getContents();
            for (int i = 0; i < messageInfoCollection.size(); i++)
            {
                // Get contact information in MapiContact instance
                MessageInfo messageInfo = (MessageInfo)messageInfoCollection.get(i);
                MapiCalendar calendar = (MapiCalendar)pst.extractMessage(messageInfo).toMapiMessageItem();

                // Display contact information on screen
                System.out.println("Subject: " + calendar.getSubject());
                System.out.println("Location: " + calendar.getLocation());

                // save the contact to disk in VCF format
//                calendar.save(strBaseFolder + "Contacts\\" + calendar.getNameInfo().getDisplayName() + ".vcf", ContactSaveFormat.V_CARD);
            }
        }
        catch (Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void setLicense()
    {
        try
        {
            // Set license. Provide full path and license file name
            com.aspose.network.License licNetwork = new com.aspose.network.License();
            licNetwork.setLicense(strBaseFolder + "Aspose.Total.Product.Family.lic");
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }
}
