//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Network for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
// This demo explains the steps to load an Outlook PST file and display the message information
// from all folders using recursive method
//==========================================================================================================//

import com.aspose.network.FolderInfo;
import com.aspose.network.MessageInfo;
import com.aspose.network.MessageInfoCollection;
import com.aspose.network.PersonalStorage;

public class PSTGetMessages
{
    // Base folder to load and save files used in this demo
    private static String strBaseFolder = "D:\\Data\\Aspose\\resources\\";

    public static void main(String[] args)
    {
        // Set license
        setLicense();

        String pstFileName = strBaseFolder + "Outlook.pst";

        try
        {
            // load the Outlook PST file
            PersonalStorage pst = PersonalStorage.fromFile(pstFileName);

            // get the root folder
            FolderInfo folderInfo = pst.getRootFolder();

            // call the recursive method to display the folder contents
            DisplayFolderContents(folderInfo, pst);
        }
        catch (Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }

    private static void DisplayFolderContents(FolderInfo folderInfo, PersonalStorage pst)
    {
        // display the folder name
        System.out.println("Folder: " + folderInfo.getDisplayName());
        // display information about messages inside this folder
        MessageInfoCollection messageInfoCollection = folderInfo.getContents();
        for (int i = 0; i < messageInfoCollection.size(); i++)
        {
            MessageInfo messageInfo = (MessageInfo) messageInfoCollection.get(i);
            System.out.println("Subject: " + messageInfo.getSubject());
            System.out.println("Sender: " + messageInfo.getSenderRepresentativeName());
            System.out.println("To: " + messageInfo.getDisplayTo());
            System.out.println("CC: " + messageInfo.getDisplayCC());
            System.out.println("EntryID: " + messageInfo.getEntryIdString());
        }

        // call this method recursively for each subfolder
        if (folderInfo.hasSubFolders() == true)
        {
            for (int i = 0; i < folderInfo.getSubFolders().size(); i++)
            {
                FolderInfo subfolderInfo = (FolderInfo) folderInfo.getSubFolders().get(i);
                DisplayFolderContents(subfolderInfo, pst);
            }
        }
    }

    private static void setLicense()
    {
        try
        {
            // Set license. Provide full path and license file name
            com.aspose.network.License licNetwork = new com.aspose.network.License();
            licNetwork.setLicense(strBaseFolder + "Aspose.Total.Product.Family.lic");
        }
        catch(Exception ex)
        {
            System.out.println(ex.getMessage());
        }
    }
}
